retry

Function retry 

pub async fn retry<T, F, Fut>(
    policy: &RetryPolicy,
    kind: OpKind,
    op: F,
) -> Result<T>
where F: FnMut() -> Fut, Fut: Future<Output = Result<T>>,
Run op, retrying per policy while failures stay retryable.

Errors

Returns the last error once attempts are exhausted or the failure is not retryable for this OpKind.