Module output

Module output 

Output formatting for CLI results.

Supports table (via comfy-table), JSON, and CSV output formats. All formatters operate on types implementing Formattable.

Enums

OutputFormat
Output format selection.

Traits

Formattable
Trait for types that can be rendered in table or CSV format.

Functions

format_output
Format a list of items in the specified output format.